pub struct ChevronIcons {
pub collapsed: Option<SharedString>,
pub expanded: Option<SharedString>,
}Expand description
The icons used for chevrons.
Fields
collapsed: Option<SharedString>The path to the icon to use for a collapsed chevron.
expanded: Option<SharedString>The path to the icon to use for an expanded chevron.