pub struct ChevronIconsContent {
pub collapsed: Option<SharedString>,
pub expanded: Option<SharedString>,
}Fields
collapsed: Option<SharedString>expanded: Option<SharedString>Trait Implementations
Sourceimpl Clone for ChevronIconsContent
impl Clone for ChevronIconsContent
Sourcefn clone(&self) -> ChevronIconsContent
fn clone(&self) -> ChevronIconsContent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChevronIconsContent
impl Debug for ChevronIconsContent
Sourceimpl Default for ChevronIconsContent
impl Default for ChevronIconsContent
Sourcefn default() -> ChevronIconsContent
fn default() -> ChevronIconsContent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ChevronIconsContent
impl<'de> Deserialize<'de> for ChevronIconsContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChevronIconsContent
impl JsonSchema for ChevronIconsContent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChevronIconsContent
impl RefUnwindSafe for ChevronIconsContent
impl Send for ChevronIconsContent
impl Sync for ChevronIconsContent
impl Unpin for ChevronIconsContent
impl UnsafeUnpin for ChevronIconsContent
impl UnwindSafe for ChevronIconsContent