pub struct ColorScaleStep(/* private fields */);Expand description
A collection of colors that are used to style the UI.
Each step has a semantic meaning, and is used to style different parts of the UI.
Implementations
Sourceimpl ColorScaleStep
impl ColorScaleStep
pub const ONE: Self
pub const TWO: Self
pub const THREE: Self
pub const FOUR: Self
pub const FIVE: Self
pub const SIX: Self
pub const SEVEN: Self
pub const EIGHT: Self
pub const NINE: Self
pub const TEN: Self
pub const ELEVEN: Self
pub const TWELVE: Self
Sourcepub const ALL: [ColorScaleStep; 12]
pub const ALL: [ColorScaleStep; 12]
All of the steps in a ColorScale.