pub struct DirectoryIcons {
pub collapsed: Option<SharedString>,
pub expanded: Option<SharedString>,
}Expand description
The icons used for directories.
Fields
collapsed: Option<SharedString>The path to the icon to use for a collapsed directory.
expanded: Option<SharedString>The path to the icon to use for an expanded directory.