pub struct FontFamilyCache { /* private fields */ }Expand description
A cache for the list of font families.
Listing the available font families from the text system is expensive, so we do it once and then use the cached values each render.
Implementations
Sourceimpl FontFamilyCache
impl FontFamilyCache
Sourcepub fn init_global(cx: &mut App)
pub fn init_global(cx: &mut App)
Initializes the global font family cache.
Sourcepub fn list_font_families(&self, cx: &App) -> Vec<SharedString>
pub fn list_font_families(&self, cx: &App) -> Vec<SharedString>
Returns the list of font families.
Sourcepub fn try_list_font_families(&self) -> Option<Vec<SharedString>>
pub fn try_list_font_families(&self) -> Option<Vec<SharedString>>
Returns the list of font families if they have been loaded