pub struct IconTheme {
pub id: String,
pub name: SharedString,
pub appearance: Appearance,
pub directory_icons: DirectoryIcons,
pub named_directory_icons: HashMap<String, DirectoryIcons>,
pub chevron_icons: ChevronIcons,
pub file_stems: HashMap<String, String>,
pub file_suffixes: HashMap<String, String>,
pub file_icons: HashMap<String, IconDefinition>,
}Expand description
An icon theme.
Fields
id: StringThe unique ID for the icon theme.
name: SharedStringThe name of the icon theme.
appearance: AppearanceThe appearance of the icon theme (e.g., light or dark).
directory_icons: DirectoryIconsThe icons used for directories.
named_directory_icons: HashMap<String, DirectoryIcons>The icons used for named directories.
chevron_icons: ChevronIconsThe icons used for chevrons.
file_stems: HashMap<String, String>The mapping of file stems to their associated icon keys.
file_suffixes: HashMap<String, String>The mapping of file suffixes to their associated icon keys.
file_icons: HashMap<String, IconDefinition>The mapping of icon keys to icon definitions.