pub struct PlayerColors(pub Vec<PlayerColor>);Expand description
A collection of colors that are used to color players in the editor.
The first color is always the local player’s color, usually a blue.
The rest of the default colors crisscross back and forth on the color wheel so that the colors are as distinct as possible.
Tuple Fields
0: Vec<PlayerColor>Implementations
Sourceimpl PlayerColors
impl PlayerColors
pub fn local(&self) -> PlayerColor
pub fn agent(&self) -> PlayerColor
pub fn absent(&self) -> PlayerColor
pub fn read_only(&self) -> PlayerColor
pub fn color_for_participant(&self, participant_index: u32) -> PlayerColor