Theme

Struct Theme 

pub struct Theme {
    pub id: String,
    pub name: SharedString,
    pub appearance: Appearance,
    pub styles: ThemeStyles,
}
A theme is the primary mechanism for defining the appearance of the UI.

Fields

id: String

The unique identifier for the theme.

name: SharedString

The name of the theme.

appearance: Appearance

The appearance of the theme (light or dark).

styles: ThemeStyles

The colors and other styles for the theme.

Implementations

Source

impl Theme

pub fn system(&self) -> &SystemColors

Returns the SystemColors for the theme.

pub fn accents(&self) -> &AccentColors

Returns the AccentColors for the theme.

pub fn players(&self) -> &PlayerColors

Returns the PlayerColors for the theme.

pub fn colors(&self) -> &ThemeColors

Returns the ThemeColors for the theme.

pub fn syntax(&self) -> &Arc<SyntaxTheme>

Returns the SyntaxTheme for the theme.

pub fn status(&self) -> &StatusColors

Returns the StatusColors for the theme.

pub fn appearance(&self) -> Appearance

Returns the Appearance for the theme.

pub fn window_background_appearance(&self) -> WindowBackgroundAppearance

Returns the WindowBackgroundAppearance for the theme.

pub fn darken(&self, color: Hsla, light_amount: f32, dark_amount: f32) -> Hsla

Darkens the color by reducing its lightness. The resulting lightness is clamped to ensure it doesn’t go below 0.0.

The first value darkens light appearance mode, the second darkens appearance dark mode.

Note: This is a tentative solution and may be replaced with a more robust color system.