ThemeFamily

Struct ThemeFamily 

pub struct ThemeFamily {
    pub id: String,
    pub name: SharedString,
    pub author: SharedString,
    pub themes: Vec<Theme>,
    pub scales: ColorScales,
}
A theme family is a grouping of themes under a single name.

For example, the “One” theme family contains the “One Light” and “One Dark” themes.

It can also be used to package themes with many variants.

For example, the “Atelier” theme family contains “Cave”, “Dune”, “Estuary”, “Forest”, “Heath”, etc.

Fields

id: String

The unique identifier for the theme family.

name: SharedString

The name of the theme family. This will be displayed in the UI, such as when adding or removing a theme family.

author: SharedString

The author of the theme family.

themes: Vec<Theme>

The Themes in the family.

scales: ColorScales

The color scales used by the themes in the family. Note: This will be removed in the future.