ThemeRegistry

Struct ThemeRegistry 

pub struct ThemeRegistry { /* private fields */ }
The registry for themes.

Implementations

Source

impl ThemeRegistry

pub fn global(cx: &App) -> Arc<Self>

Returns the global ThemeRegistry.

pub fn default_global(cx: &mut App) -> Arc<Self>

Returns the global ThemeRegistry.

Inserts a default ThemeRegistry if one does not yet exist.

pub fn try_global(cx: &mut App) -> Option<Arc<Self>>

Returns the global ThemeRegistry if it exists.

pub fn assets(&self) -> &dyn AssetSource

Returns the asset source used by this registry.

pub fn new(assets: Box<dyn AssetSource>) -> Self

Creates a new ThemeRegistry with the given AssetSource.

pub fn extensions_loaded(&self) -> bool

Returns whether the extensions have been loaded.

pub fn set_extensions_loaded(&self)

Sets the flag indicating that the extensions have loaded.

pub fn insert_theme_families( &self, families: impl IntoIterator<Item = ThemeFamily>, )

Inserts the given theme families into the registry.

pub fn insert_themes(&self, themes: impl IntoIterator<Item = Theme>)

Inserts the given themes into the registry.

pub fn remove_user_themes(&self, themes_to_remove: &[SharedString])

Removes the themes with the given names from the registry.

pub fn clear(&self)

Removes all themes from the registry.

pub fn list_names(&self) -> Vec<SharedString>

Returns the names of all themes in the registry.

pub fn list(&self) -> Vec<ThemeMeta>

Returns the metadata of all themes in the registry.

pub fn get(&self, name: &str) -> Result<Arc<Theme>, ThemeNotFoundError>

Returns the theme with the given name.

pub fn default_icon_theme( &self, ) -> Result<Arc<IconTheme>, IconThemeNotFoundError>

Returns the default icon theme.

pub fn list_icon_themes(&self) -> Vec<ThemeMeta>

Returns the metadata of all icon themes in the registry.

pub fn get_icon_theme( &self, name: &str, ) -> Result<Arc<IconTheme>, IconThemeNotFoundError>

Returns the icon theme with the specified name.

pub fn remove_icon_themes(&self, icon_themes_to_remove: &[SharedString])

Removes the icon themes with the given names from the registry.

pub fn load_icon_theme( &self, icon_theme_family: IconThemeFamilyContent, icons_root_dir: &Path, ) -> Result<()>

Loads the icon theme from the icon theme family and adds it to the registry.

The icons_root_dir parameter indicates the root directory from which the relative paths to icons in the theme should be resolved against.