pub struct StatusColors {Show 42 fields
pub conflict: Hsla,
pub conflict_background: Hsla,
pub conflict_border: Hsla,
pub created: Hsla,
pub created_background: Hsla,
pub created_border: Hsla,
pub deleted: Hsla,
pub deleted_background: Hsla,
pub deleted_border: Hsla,
pub error: Hsla,
pub error_background: Hsla,
pub error_border: Hsla,
pub hidden: Hsla,
pub hidden_background: Hsla,
pub hidden_border: Hsla,
pub hint: Hsla,
pub hint_background: Hsla,
pub hint_border: Hsla,
pub ignored: Hsla,
pub ignored_background: Hsla,
pub ignored_border: Hsla,
pub info: Hsla,
pub info_background: Hsla,
pub info_border: Hsla,
pub modified: Hsla,
pub modified_background: Hsla,
pub modified_border: Hsla,
pub predictive: Hsla,
pub predictive_background: Hsla,
pub predictive_border: Hsla,
pub renamed: Hsla,
pub renamed_background: Hsla,
pub renamed_border: Hsla,
pub success: Hsla,
pub success_background: Hsla,
pub success_border: Hsla,
pub unreachable: Hsla,
pub unreachable_background: Hsla,
pub unreachable_border: Hsla,
pub warning: Hsla,
pub warning_background: Hsla,
pub warning_border: Hsla,
}Fields
conflict: HslaIndicates some kind of conflict, like a file changed on disk while it was open, or merge conflicts in a Git repository.
conflict_background: Hslaconflict_border: Hslacreated: HslaIndicates something new, like a new file added to a Git repository.
created_background: Hslacreated_border: Hsladeleted: HslaIndicates that something no longer exists, like a deleted file.
deleted_background: Hsladeleted_border: Hslaerror: HslaIndicates a system error, a failed operation or a diagnostic error.
error_background: Hslaerror_border: HslaRepresents a hidden status, such as a file being hidden in a file tree.
hint: HslaIndicates a hint or some kind of additional information.
hint_background: Hslahint_border: Hslaignored: HslaIndicates that something is deliberately ignored, such as a file or operation ignored by Git.
ignored_background: Hslaignored_border: Hslainfo: HslaRepresents informational status updates or messages.
info_background: Hslainfo_border: Hslamodified: HslaIndicates a changed or altered status, like a file that has been edited.
modified_background: Hslamodified_border: Hslapredictive: HslaIndicates something that is predicted, like automatic code completion, or generated code.
predictive_background: Hslapredictive_border: Hslarenamed: HslaRepresents a renamed status, such as a file that has been renamed.
renamed_background: Hslarenamed_border: Hslasuccess: HslaIndicates a successful operation or task completion.
success_background: Hslasuccess_border: Hslaunreachable: HslaIndicates some kind of unreachable status, like a block of code that can never be reached.
unreachable_background: Hslaunreachable_border: Hslawarning: HslaRepresents a warning status, like an operation that is about to fail.
warning_background: Hslawarning_border: HslaImplementations
Sourceimpl StatusColors
impl StatusColors
pub fn dark() -> Self
pub fn light() -> Self
pub fn diagnostic(&self) -> DiagnosticColors