pub struct Theme {
pub id: String,
pub name: SharedString,
pub appearance: Appearance,
pub styles: ThemeStyles,
}Expand description
A theme is the primary mechanism for defining the appearance of the UI.
Fields
id: StringThe unique identifier for the theme.
name: SharedStringThe name of the theme.
appearance: AppearanceThe appearance of the theme (light or dark).
styles: ThemeStylesThe colors and other styles for the theme.
Implementations
Sourceimpl Theme
impl Theme
Sourcepub fn system(&self) -> &SystemColors
pub fn system(&self) -> &SystemColors
Returns the SystemColors for the theme.
Sourcepub fn accents(&self) -> &AccentColors
pub fn accents(&self) -> &AccentColors
Returns the AccentColors for the theme.
Sourcepub fn players(&self) -> &PlayerColors
pub fn players(&self) -> &PlayerColors
Returns the PlayerColors for the theme.
Sourcepub fn colors(&self) -> &ThemeColors
pub fn colors(&self) -> &ThemeColors
Returns the ThemeColors for the theme.
Sourcepub fn syntax(&self) -> &Arc<SyntaxTheme> ⓘ
pub fn syntax(&self) -> &Arc<SyntaxTheme> ⓘ
Returns the SyntaxTheme for the theme.
Sourcepub fn status(&self) -> &StatusColors
pub fn status(&self) -> &StatusColors
Returns the StatusColors for the theme.
Sourcepub fn appearance(&self) -> Appearance
pub fn appearance(&self) -> Appearance
Returns the Appearance for the theme.
Sourcepub fn window_background_appearance(&self) -> WindowBackgroundAppearance
pub fn window_background_appearance(&self) -> WindowBackgroundAppearance
Returns the WindowBackgroundAppearance for the theme.
Sourcepub fn darken(&self, color: Hsla, light_amount: f32, dark_amount: f32) -> Hsla
pub fn darken(&self, color: Hsla, light_amount: f32, dark_amount: f32) -> Hsla
Darkens the color by reducing its lightness. The resulting lightness is clamped to ensure it doesn’t go below 0.0.
The first value darkens light appearance mode, the second darkens appearance dark mode.
Note: This is a tentative solution and may be replaced with a more robust color system.