pub struct ThemeColors {Show 137 fields
pub border: Hsla,
pub border_variant: Hsla,
pub border_focused: Hsla,
pub border_selected: Hsla,
pub border_transparent: Hsla,
pub border_disabled: Hsla,
pub elevated_surface_background: Hsla,
pub surface_background: Hsla,
pub background: Hsla,
pub element_background: Hsla,
pub element_hover: Hsla,
pub element_active: Hsla,
pub element_selected: Hsla,
pub element_selection_background: Hsla,
pub element_disabled: Hsla,
pub drop_target_background: Hsla,
pub drop_target_border: Hsla,
pub ghost_element_background: Hsla,
pub ghost_element_hover: Hsla,
pub ghost_element_active: Hsla,
pub ghost_element_selected: Hsla,
pub ghost_element_disabled: Hsla,
pub text: Hsla,
pub text_muted: Hsla,
pub text_placeholder: Hsla,
pub text_disabled: Hsla,
pub text_accent: Hsla,
pub icon: Hsla,
pub icon_muted: Hsla,
pub icon_disabled: Hsla,
pub icon_placeholder: Hsla,
pub icon_accent: Hsla,
pub debugger_accent: Hsla,
pub status_bar_background: Hsla,
pub title_bar_background: Hsla,
pub title_bar_inactive_background: Hsla,
pub toolbar_background: Hsla,
pub tab_bar_background: Hsla,
pub tab_inactive_background: Hsla,
pub tab_active_background: Hsla,
pub search_match_background: Hsla,
pub search_active_match_background: Hsla,
pub panel_background: Hsla,
pub panel_focused_border: Hsla,
pub panel_indent_guide: Hsla,
pub panel_indent_guide_hover: Hsla,
pub panel_indent_guide_active: Hsla,
pub panel_overlay_background: Hsla,
pub panel_overlay_hover: Hsla,
pub pane_focused_border: Hsla,
pub pane_group_border: Hsla,
pub scrollbar_thumb_background: Hsla,
pub scrollbar_thumb_hover_background: Hsla,
pub scrollbar_thumb_active_background: Hsla,
pub scrollbar_thumb_border: Hsla,
pub scrollbar_track_background: Hsla,
pub scrollbar_track_border: Hsla,
pub minimap_thumb_background: Hsla,
pub minimap_thumb_hover_background: Hsla,
pub minimap_thumb_active_background: Hsla,
pub minimap_thumb_border: Hsla,
pub vim_normal_background: Hsla,
pub vim_insert_background: Hsla,
pub vim_replace_background: Hsla,
pub vim_visual_background: Hsla,
pub vim_visual_line_background: Hsla,
pub vim_visual_block_background: Hsla,
pub vim_yank_background: Hsla,
pub vim_helix_jump_label_foreground: Hsla,
pub vim_helix_normal_background: Hsla,
pub vim_helix_select_background: Hsla,
pub vim_normal_foreground: Hsla,
pub vim_insert_foreground: Hsla,
pub vim_replace_foreground: Hsla,
pub vim_visual_foreground: Hsla,
pub vim_visual_line_foreground: Hsla,
pub vim_visual_block_foreground: Hsla,
pub vim_helix_normal_foreground: Hsla,
pub vim_helix_select_foreground: Hsla,
pub editor_foreground: Hsla,
pub editor_background: Hsla,
pub editor_gutter_background: Hsla,
pub editor_subheader_background: Hsla,
pub editor_active_line_background: Hsla,
pub editor_highlighted_line_background: Hsla,
pub editor_debugger_active_line_background: Hsla,
pub editor_line_number: Hsla,
pub editor_active_line_number: Hsla,
pub editor_hover_line_number: Hsla,
pub editor_invisible: Hsla,
pub editor_wrap_guide: Hsla,
pub editor_active_wrap_guide: Hsla,
pub editor_indent_guide: Hsla,
pub editor_indent_guide_active: Hsla,
pub editor_document_highlight_read_background: Hsla,
pub editor_document_highlight_write_background: Hsla,
pub editor_document_highlight_bracket_background: Hsla,
pub terminal_background: Hsla,
pub terminal_foreground: Hsla,
pub terminal_bright_foreground: Hsla,
pub terminal_dim_foreground: Hsla,
pub terminal_ansi_background: Hsla,
pub terminal_ansi_black: Hsla,
pub terminal_ansi_bright_black: Hsla,
pub terminal_ansi_dim_black: Hsla,
pub terminal_ansi_red: Hsla,
pub terminal_ansi_bright_red: Hsla,
pub terminal_ansi_dim_red: Hsla,
pub terminal_ansi_green: Hsla,
pub terminal_ansi_bright_green: Hsla,
pub terminal_ansi_dim_green: Hsla,
pub terminal_ansi_yellow: Hsla,
pub terminal_ansi_bright_yellow: Hsla,
pub terminal_ansi_dim_yellow: Hsla,
pub terminal_ansi_blue: Hsla,
pub terminal_ansi_bright_blue: Hsla,
pub terminal_ansi_dim_blue: Hsla,
pub terminal_ansi_magenta: Hsla,
pub terminal_ansi_bright_magenta: Hsla,
pub terminal_ansi_dim_magenta: Hsla,
pub terminal_ansi_cyan: Hsla,
pub terminal_ansi_bright_cyan: Hsla,
pub terminal_ansi_dim_cyan: Hsla,
pub terminal_ansi_white: Hsla,
pub terminal_ansi_bright_white: Hsla,
pub terminal_ansi_dim_white: Hsla,
pub link_text_hover: Hsla,
pub version_control_added: Hsla,
pub version_control_deleted: Hsla,
pub version_control_modified: Hsla,
pub version_control_renamed: Hsla,
pub version_control_conflict: Hsla,
pub version_control_ignored: Hsla,
pub version_control_word_added: Hsla,
pub version_control_word_deleted: Hsla,
pub version_control_conflict_marker_ours: Hsla,
pub version_control_conflict_marker_theirs: Hsla,
}Fields
border: HslaBorder color. Used for most borders, is usually a high contrast color.
border_variant: HslaBorder color. Used for deemphasized borders, like a visual divider between two sections
border_focused: HslaBorder color. Used for focused elements, like keyboard focused list item.
border_selected: HslaBorder color. Used for selected elements, like an active search filter or selected checkbox.
border_transparent: HslaBorder color. Used for transparent borders. Used for placeholder borders when an element gains a border on state change.
border_disabled: HslaBorder color. Used for disabled elements, like a disabled input or button.
elevated_surface_background: HslaBorder color. Used for elevated surfaces, like a context menu, popup, or dialog.
surface_background: HslaBackground Color. Used for grounded surfaces like a panel or tab.
background: HslaBackground Color. Used for the app background and blank panels or windows.
element_background: HslaBackground Color. Used for the background of an element that should have a different background than the surface it’s on.
Elements might include: Buttons, Inputs, Checkboxes, Radio Buttons…
For an element that should have the same background as the surface it’s on, use ghost_element_background.
element_hover: HslaBackground Color. Used for the hover state of an element that should have a different background than the surface it’s on.
Hover states are triggered by the mouse entering an element, or a finger touching an element on a touch screen.
element_active: HslaBackground Color. Used for the active state of an element that should have a different background than the surface it’s on.
Active states are triggered by the mouse button being pressed down on an element, or the Return button or other activator being pressed.
element_selected: HslaBackground Color. Used for the selected state of an element that should have a different background than the surface it’s on.
Selected states are triggered by the element being selected (or “activated”) by the user.
This could include a selected checkbox, a toggleable button that is toggled on, etc.
element_selection_background: HslaBackground Color. Used for the background of selections in a UI element.
element_disabled: HslaBackground Color. Used for the disabled state of an element that should have a different background than the surface it’s on.
Disabled states are shown when a user cannot interact with an element, like a disabled button or input.
drop_target_background: HslaBackground Color. Used for the area that shows where a dragged element will be dropped.
drop_target_border: HslaBorder Color. Used for the border that shows where a dragged element will be dropped.
ghost_element_background: HslaUsed for the background of a ghost element that should have the same background as the surface it’s on.
Elements might include: Buttons, Inputs, Checkboxes, Radio Buttons…
For an element that should have a different background than the surface it’s on, use element_background.
ghost_element_hover: HslaBackground Color. Used for the hover state of a ghost element that should have the same background as the surface it’s on.
Hover states are triggered by the mouse entering an element, or a finger touching an element on a touch screen.
ghost_element_active: HslaBackground Color. Used for the active state of a ghost element that should have the same background as the surface it’s on.
Active states are triggered by the mouse button being pressed down on an element, or the Return button or other activator being pressed.
ghost_element_selected: HslaBackground Color. Used for the selected state of a ghost element that should have the same background as the surface it’s on.
Selected states are triggered by the element being selected (or “activated”) by the user.
This could include a selected checkbox, a toggleable button that is toggled on, etc.
ghost_element_disabled: HslaBackground Color. Used for the disabled state of a ghost element that should have the same background as the surface it’s on.
Disabled states are shown when a user cannot interact with an element, like a disabled button or input.
text: HslaText Color. Default text color used for most text.
text_muted: HslaText Color. Color of muted or deemphasized text. It is a subdued version of the standard text color.
text_placeholder: HslaText Color. Color of the placeholder text typically shown in input fields to guide the user to enter valid data.
text_disabled: HslaText Color. Color used for text denoting disabled elements. Typically, the color is faded or grayed out to emphasize the disabled state.
text_accent: HslaText Color. Color used for emphasis or highlighting certain text, like an active filter or a matched character in a search.
icon: HslaFill Color. Used for the default fill color of an icon.
icon_muted: HslaFill Color. Used for the muted or deemphasized fill color of an icon.
This might be used to show an icon in an inactive pane, or to deemphasize a series of icons to give them less visual weight.
icon_disabled: HslaFill Color. Used for the disabled fill color of an icon.
Disabled states are shown when a user cannot interact with an element, like a icon button.
icon_placeholder: HslaFill Color. Used for the placeholder fill color of an icon.
This might be used to show an icon in an input that disappears when the user enters text.
icon_accent: HslaFill Color. Used for the accent fill color of an icon.
This might be used to show when a toggleable icon button is selected.
debugger_accent: HslaColor used to accent some debugger elements Is used by breakpoints
status_bar_background: Hslatitle_bar_background: Hslatitle_bar_inactive_background: Hslatoolbar_background: Hslatab_bar_background: Hslatab_inactive_background: Hslatab_active_background: Hslasearch_match_background: Hslasearch_active_match_background: Hslapanel_background: Hslapanel_focused_border: Hslapanel_indent_guide: Hslapanel_indent_guide_hover: Hslapanel_indent_guide_active: Hslapanel_overlay_background: HslaThe color of the overlay surface on top of panel.
panel_overlay_hover: HslaThe color of the overlay surface on top of panel when hovered over.
pane_focused_border: Hslapane_group_border: Hslascrollbar_thumb_background: HslaThe color of the scrollbar thumb.
scrollbar_thumb_hover_background: HslaThe color of the scrollbar thumb when hovered over.
scrollbar_thumb_active_background: HslaThe color of the scrollbar thumb whilst being actively dragged.
scrollbar_thumb_border: HslaThe border color of the scrollbar thumb.
scrollbar_track_background: HslaThe background color of the scrollbar track.
scrollbar_track_border: HslaThe border color of the scrollbar track.
minimap_thumb_background: HslaThe color of the minimap thumb.
minimap_thumb_hover_background: HslaThe color of the minimap thumb when hovered over.
minimap_thumb_active_background: HslaThe color of the minimap thumb whilst being actively dragged.
minimap_thumb_border: HslaThe border color of the minimap thumb.
vim_normal_background: HslaBackground color for Vim Normal mode indicator.
vim_insert_background: HslaBackground color for Vim Insert mode indicator.
vim_replace_background: HslaBackground color for Vim Replace mode indicator.
vim_visual_background: HslaBackground color for Vim Visual mode indicator.
vim_visual_line_background: HslaBackground color for Vim Visual Line mode indicator.
vim_visual_block_background: HslaBackground color for Vim Visual Block mode indicator.
vim_yank_background: HslaBackground color for Vim yank highlight.
vim_helix_jump_label_foreground: HslaForeground color for Helix jump labels.
vim_helix_normal_background: HslaBackground color for Vim Helix Normal mode indicator.
vim_helix_select_background: HslaBackground color for Vim Helix Select mode indicator.
vim_normal_foreground: HslaForeground color for Vim Normal mode indicator.
vim_insert_foreground: HslaForeground color for Vim Insert mode indicator.
vim_replace_foreground: HslaForeground color for Vim Replace mode indicator.
vim_visual_foreground: HslaForeground color for Vim Visual mode indicator.
vim_visual_line_foreground: HslaForeground color for Vim Visual Line mode indicator.
vim_visual_block_foreground: HslaForeground color for Vim Visual Block mode indicator.
vim_helix_normal_foreground: HslaForeground color for Vim Helix Normal mode indicator.
vim_helix_select_foreground: HslaForeground color for Vim Helix Select mode indicator.
editor_foreground: Hslaeditor_background: Hslaeditor_gutter_background: Hslaeditor_subheader_background: Hslaeditor_active_line_background: Hslaeditor_highlighted_line_background: Hslaeditor_debugger_active_line_background: HslaLine color of the line a debugger is currently stopped at
editor_line_number: HslaText Color. Used for the text of the line number in the editor gutter.
editor_active_line_number: HslaText Color. Used for the text of the line number in the editor gutter when the line is highlighted.
editor_hover_line_number: HslaText Color. Used for the text of the line number in the editor gutter when the line is hovered over.
editor_invisible: HslaText Color. Used to mark invisible characters in the editor.
Example: spaces, tabs, carriage returns, etc.
editor_wrap_guide: Hslaeditor_active_wrap_guide: Hslaeditor_indent_guide: Hslaeditor_indent_guide_active: Hslaeditor_document_highlight_read_background: HslaRead-access of a symbol, like reading a variable.
A document highlight is a range inside a text document which deserves special attention. Usually a document highlight is visualized by changing the background color of its range.
editor_document_highlight_write_background: HslaRead-access of a symbol, like reading a variable.
A document highlight is a range inside a text document which deserves special attention. Usually a document highlight is visualized by changing the background color of its range.
editor_document_highlight_bracket_background: HslaHighlighted brackets background color.
Matching brackets in the cursor scope are highlighted with this background color.
terminal_background: HslaTerminal layout background color.
terminal_foreground: HslaTerminal foreground color.
terminal_bright_foreground: HslaBright terminal foreground color.
terminal_dim_foreground: HslaDim terminal foreground color.
terminal_ansi_background: HslaTerminal ANSI background color.
terminal_ansi_black: HslaBlack ANSI terminal color.
terminal_ansi_bright_black: HslaBright black ANSI terminal color.
terminal_ansi_dim_black: HslaDim black ANSI terminal color.
terminal_ansi_red: HslaRed ANSI terminal color.
terminal_ansi_bright_red: HslaBright red ANSI terminal color.
terminal_ansi_dim_red: HslaDim red ANSI terminal color.
terminal_ansi_green: HslaGreen ANSI terminal color.
terminal_ansi_bright_green: HslaBright green ANSI terminal color.
terminal_ansi_dim_green: HslaDim green ANSI terminal color.
terminal_ansi_yellow: HslaYellow ANSI terminal color.
terminal_ansi_bright_yellow: HslaBright yellow ANSI terminal color.
terminal_ansi_dim_yellow: HslaDim yellow ANSI terminal color.
terminal_ansi_blue: HslaBlue ANSI terminal color.
terminal_ansi_bright_blue: HslaBright blue ANSI terminal color.
terminal_ansi_dim_blue: HslaDim blue ANSI terminal color.
terminal_ansi_magenta: HslaMagenta ANSI terminal color.
terminal_ansi_bright_magenta: HslaBright magenta ANSI terminal color.
terminal_ansi_dim_magenta: HslaDim magenta ANSI terminal color.
terminal_ansi_cyan: HslaCyan ANSI terminal color.
terminal_ansi_bright_cyan: HslaBright cyan ANSI terminal color.
terminal_ansi_dim_cyan: HslaDim cyan ANSI terminal color.
terminal_ansi_white: HslaWhite ANSI terminal color.
terminal_ansi_bright_white: HslaBright white ANSI terminal color.
terminal_ansi_dim_white: HslaDim white ANSI terminal color.
link_text_hover: HslaRepresents a link text hover color.
version_control_added: HslaRepresents an added entry or hunk in vcs, like git.
version_control_deleted: HslaRepresents a deleted entry in version control systems.
version_control_modified: HslaRepresents a modified entry in version control systems.
version_control_renamed: HslaRepresents a renamed entry in version control systems.
version_control_conflict: HslaRepresents a conflicting entry in version control systems.
version_control_ignored: HslaRepresents an ignored entry in version control systems.
version_control_word_added: HslaRepresents an added word in a word diff.
version_control_word_deleted: HslaRepresents a deleted word in a word diff.
version_control_conflict_marker_ours: HslaRepresents the “ours” region of a merge conflict.
version_control_conflict_marker_theirs: HslaRepresents the “theirs” region of a merge conflict.
Implementations
Sourceimpl ThemeColors
The default colors for the theme.
impl ThemeColors
The default colors for the theme.
Themes that do not specify all colors are refined off of these defaults.
Sourceimpl ThemeColors
impl ThemeColors
pub fn color(&self, field: ThemeColorField) -> Hsla
pub fn iter(&self) -> impl Iterator<Item = (ThemeColorField, Hsla)> + '_
pub fn to_vec(&self) -> Vec<(ThemeColorField, Hsla)>